ApMediationSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ApMediationSdkPlatform
Implementers

Constructors

ApMediationSdkPlatform()
Constructs a ApMediationSdkPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableDebug(bool isEnable) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ApMediationSdkPlatform
The default instance of ApMediationSdkPlatform to use.
getter/setter pair